@@ -55,7 +55,14 @@ class AwsathenaDataSource(ToucanDataSource):
         super().__init__(**data)
         # Named parameters need to be passed as `:name`
         # (see https://aws-data-wrangler.readthedocs.io/en/stable/stubs/awswrangler.athena.read_sql_query.html)
-        self.query, self.parameters = sanitize_query(self.query, self.parameters, lambda x: f':{x}')
+        self.query, self.parameters = sanitize_query(
+            self.query, self.parameters, athena_variable_transformer
+        )
+
+
+def athena_variable_transformer(variable: str):
+    """Add surrounding for parameters injection"""
+    return f':{variable};'
 
 
 class AwsathenaConnector(ToucanConnector, DiscoverableConnector):
@@ -169,11 +176,21 @@ class AwsathenaConnector(ToucanConnector, DiscoverableConnector):
             permissions_query = apply_query_parameters(permissions_query, data_source.parameters)
             df = df.query(permissions_query)
 
+        fetched_row_count = len(df)
         return DataSlice(
             df,
             stats=DataStats(
-                total_returned_rows=len(df),
-                total_rows=len(df),
+                total_returned_rows=fetched_row_count,
+                # FIXME: Dirty hack to make pagination work in previews. Currently, the FE considers
+                # that there are 0 rows if total_rows is null. At some point, we should probably
+                # implement cursor-based pagination.
+                #
+                # This is buggy if the total row count is actually equal to
+                # offset + fetched_row_count, because we will display a "next page" when there isn't
+                # one
+                total_rows=offset + fetched_row_count
+                if limit is None
+                else offset + fetched_row_count + 1,
                 df_memory_size=df.memory_usage().sum(),
             ),
         )
